Description: Pyjamas Python Web Widgets and Javascript Compiler
Keywords: Python Widgets, Python Web Widgets, Python Web Widget Set, Pyjamas, AJAX, Javascript, Python Javascript Compiler, Desktop Widgets, Desktop Widget Set

pyjamas
Will and Abe's Guide to Pyjamas

Pyjamas. beautifully misunderstood, it's inspired a whole new meaning to obfuscation of what it is to be involved in Web Engine Technology via Python...

    So what's pyjamas?
        It's a widget set.
    What's a widget set?
        it's where you can do stuff.
    What kind of stuff?
        well, make things look pretty.
    Why?
        because you can see them better.
    See what?
        the stuff.
    How do you do that?
        in python.
    I like snakes.
        python isn't a snake
    Yes it is
        no it isn't
    Yes it is
        no it isn't
    Is
        Isn't
    ...
        ...

    Why would you use a snake?
        it's python
    ok why would you use python?
        because it's easy.
    What is?
        doing HTML widgets in pyjamas.
    What's pyjamas?
        It's a compiler.
    but you said it's a widget set!
        yes.  it's a compiler, too.
    make up your mind!
        no.  it's *my* project. nyer.
    You're childish!
        yes.  i'm four.
    ok.  what's HTML?
        it's this easy-peasy web stuff.
    is that like widget stuff?
        yes, only easier.
    I read up on HTML.  it sucks.
        no it doesn't.
    Yes it does.
        no it doesn't.
    Yes it does.
        doesn't
    does
        doesn't
    ...
        ...

    So why is it easier?
        because you don't need javascript.
    But you said python.
        yes.  that's the compiler bit.
    the what?
        the compiler turns python into javascript.
    But you said it's in python?
        yes but... look...
    How come you can run python on the web?
        you can't, it's javascript
    But you said it's python.  How??
        look, I said already: it's compiled to javascript.
    I read up on javascript.  it sucks.
        yes it does.
    It's as slow as a sick dog.
        yes.  that's why there's Pyjamas-Desktop.
    What's pyjamas-desktop?
        it's pyjamas, only without the javascript.
    Huh?
        and you can run it in a web engine.
    But you said you needed javascript!
        not with a web engine you don't.
    But if you need javascript, how can you run?
        with python
    But web engines don't have python on them!
        yes they do
    No they don't
        yes they do
    No they don't
        do
    don't
        do
    ...
        ...

    Ok, so how, then?
        wiv COM an' XPCOM an' Glib/Gobject
    huh?
        it's magic
    ohhhhhh.  maagiiiic.
        voodoooo.
    voodoo atchoo to you too
        thank you!
    hahaaha
        hahaha
    So how does this magic work then?
        it manipulates DOM
    What's DOM?
        It's done by the W3C
    Who are they?
        they're people with too much time on their hands.
    Ah.  do they get anything done?
        yes - lots.
    Such as?
        writing DOM
    What's DOM?
        it's this way to access HTML n stuff.
    But HTML sucks!
        yes it does when you haven't got voodoo
    Atchoo!
        bless you.
    Thank you.  So, python voodoo makes pyjamas magic?
        yes.
    How?
        same as javascript does.
    But you said there was no javascript!
        yes.
    .@?#??
        I voodoo'd you!
    hahaha
        hahaha - wooo!

    Ok, so why am I doing python pyjamas voodoo?
        because it's easy.
    HTML sucks!
        forget HTML
    But you said pyjamas uses HTML!
        it does, as DOM, only...
    How can pyjamas be any good if it does HTML??
        because... look...
    I don't wanna play with pyjamas if it uses HTML
        it doesn't - not really
    But you said it does!
        look, I'm only four, ok?
    Can we play with snakes, instead?
        yes. how about python?
    Can we paint them to look like they're in pyjamas?
        yeah!
    Yaay!

    I heard you have to run HTML in a browser.
        yes.
    Do you run pyjamas in a browser, too?
        only if you compile it to javascript.
    But you said there was no javascript?
        that's the desktop version.
    Er... how does that work, again?
        voodoo.
    Ah.  Not running on python a server, then?
        no.
    So if it's not python in a browser, and it's not python on a server...
        that's why it's voodoo.
    Ahhhh.

    Is pyjamas better than Qt4 and GTK2, then?
        yes.
    Why?
        because they suck.
    No they don't!
        yes they do
    don't
        do
    don't
        ...
    ...

    Why do Qt4 and GTK2 suck, then?
        they don't - not really
    But you said they do!
        they're good at what they do.
    But not as good as pyjamas voodoo?
        woo-woo!
    hahahaa
        hahaaa

    So, really.
        yes?
    Why is pyjamas better?
        because of DOM
    But DOM is HTML
        yes, but...
    And HTML sucks
        yes, but...
    So why is pyjamas, which is voodoo DOM without the javascript, and...
        you don't _have_ to do HTML, you can just do DOM
    But you end up producing HTML?
        yes.
    How?
        only if you get the innerHTML of a bit of DOM
    Huh?
        it's in the W3C
    But they're rocket scientists with too much time on their hands!
        yes, but veery clever ones.
    Ohhhhh... W3C voodooo
        atchoo!
    Bless you